import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

"""
"""

from functools import lru_cache
import pandas as pd
import requests
from bs4 import BeautifulSoup
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.em.em_stock_info_api as em_stock_info_api
import mns_common.component.company.company_common_service_api as company_common_service_api
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
from datetime import datetime, timedelta

mongodb_util = MongodbUtil('27017')
from tqdm import tqdm


# 同步所有映射表
@lru_cache()
def sync_stock_uid() -> pd.DataFrame:
    """
    上证e互动-代码ID映射
    https://sns.sseinfo.com/list/company.do
    :return: 代码ID映射
    :rtype: str
    """
    url = "https://sns.sseinfo.com/allcompany.do"
    data = {
        "code": "0",
        "order": "2",
        "areaId": "0",
        "page": "1",
    }
    uid_list = list()
    code_list = list()
    for page in tqdm(range(1, 74), leave=False):
        data.update({"page": page})
        r = requests.post(url, data=data)
        data_json = r.json()
        soup = BeautifulSoup(data_json["content"], "lxml")
        soup.find_all("a", attrs={"rel": "tag"})
        uid_list.extend(
            [item["uid"] for item in soup.find_all("a", attrs={"rel": "tag"})]
        )
        code_list.extend(
            [
                item.find("img")["src"].split("?")[0].split("/")[-1].split(".")[0]
                for item in soup.find_all("a", attrs={"rel": "tag"})
            ]
        )
    code_uid_df = pd.DataFrame()
    code_uid_df['symbol'] = code_list
    code_uid_df['uid'] = uid_list
    code_uid_df['_id'] = uid_list
    return code_uid_df


# 获取上海问答id
@lru_cache()
def get_sh_stock_all_uid() -> pd.DataFrame:
    return mongodb_util.find_all_data(db_name_constant.SH_INFO_UID)


# 获取深圳问答id
@lru_cache()
def get_sz_stock_all_uid() -> pd.DataFrame:
    return mongodb_util.find_all_data(db_name_constant.SZ_INFO_UID)


# 获取深圳互动回答单个ID
def get_one_sz_symbol_org_id(symbol):
    sz_info_uid_df = get_sz_stock_all_uid()
    sz_info_uid_one_df = sz_info_uid_df.loc[sz_info_uid_df['symbol'] == symbol]
    if data_frame_util.is_not_empty(sz_info_uid_one_df):
        return list(sz_info_uid_one_df['uid'])[0]
    else:
        try:
            return fetch_sz_org_id(symbol)
        except BaseException as e:
            logger.error("获取组织代码异常:{},{}", symbol, e)
            return '0'


# 获取上海互动回答单个ID
def get_one_sh_symbol_org_id(symbol):
    sh_info_uid_df = get_sh_stock_all_uid()
    sh_info_uid_one_df = sh_info_uid_df.loc[sh_info_uid_df['symbol'] == symbol]
    if data_frame_util.is_not_empty(sh_info_uid_one_df):
        return list(sh_info_uid_one_df['uid'])[0]
    else:
        return '0'


# 深圳股票-互动易-组织代码 单个获取
def fetch_sz_org_id(symbol: str = "000001") -> str:
    """
    股票-互动易-组织代码
    https://irm.cninfo.com.cn/
    :return: 组织代码
    :rtype: str
    """
    url = "https://irm.cninfo.com.cn/newircs/index/queryKeyboardInfo"
    params = {"_t": "1691144074"}
    data = {"keyWord": symbol}
    r = requests.post(url, params=params, data=data)
    data_json = r.json()
    org_id = data_json["data"][0]["secid"]
    return org_id


# 同步上证互动uid
def sync_sh_stock_uid():
    code_uid_df = sync_stock_uid()
    mongodb_util.save_mongo(code_uid_df, db_name_constant.SH_INFO_UID)


# 同步深圳互动uid
def sync_sz_stock_uid(symbol_list):
    real_time_quotes_all_stocks = em_stock_info_api.get_a_stock_info()
    de_list_company_symbols = company_common_service_api.get_de_list_company()
    real_time_quotes_all_stocks = real_time_quotes_all_stocks.loc[
        ~(real_time_quotes_all_stocks['symbol'].isin(de_list_company_symbols))]
    real_time_quotes_all_stocks = common_service_fun_api.classify_symbol(real_time_quotes_all_stocks)

    real_time_quotes_all_stocks = real_time_quotes_all_stocks.loc[
        real_time_quotes_all_stocks['classification'].isin(['S', 'C'])]
    if len(symbol_list) != 0:
        real_time_quotes_all_stocks = real_time_quotes_all_stocks.loc[
            real_time_quotes_all_stocks['symbol'].isin(symbol_list)]
    else:
        # 获取当前时间
        now_date = datetime.now()
        # 计算前7天的时间（timedelta 用于表示时间间隔）
        seven_days_ago = now_date - timedelta(days=30)
        str_day_number = int(seven_days_ago.strftime('%Y%m%d'))
        real_time_quotes_all_stocks = real_time_quotes_all_stocks.loc[
            (real_time_quotes_all_stocks['list_date'] >= str_day_number) | (
                    real_time_quotes_all_stocks['list_date'] == 19890604)]
    for stock_one in real_time_quotes_all_stocks.itertuples():
        try:
            symbol = stock_one.symbol
            uid = fetch_sz_org_id(symbol)
            result_dict = {'_id': symbol, 'symbol': symbol, 'uid': uid}
            result_dict_df = pd.DataFrame(result_dict, index=[1])
            mongodb_util.save_mongo(result_dict_df, db_name_constant.SZ_INFO_UID)
            logger.info("同步SZ互动ID:{}", stock_one.symbol)
        except Exception as e:
            logger.error("同步SZ互动ID异常:{},{}", stock_one.symbol, e)


if __name__ == '__main__':
    sz_symbol_org_id = get_one_sz_symbol_org_id('300085')
    sh_symbol_org_id = get_one_sh_symbol_org_id('600000')
    print(sz_symbol_org_id)
    print(sh_symbol_org_id)
    sync_sz_stock_uid([])
    # sync_sz_stock_uid([])
    # sync_sh_stock_uid([])



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.common_service_fun_api as common_service_fun_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.api.kpl.constant.kpl_constant as kpl_constant
import mns_common.constant.db_name_constant as db_name_constant
from functools import lru_cache
from loguru import logger

mongodb_util = MongodbUtil('27017')


def set_kpl_plate_info(company_one_df, company_one, kpl_real_time_quotes):
    try:
        if data_frame_util.is_not_empty(kpl_real_time_quotes):
            kpl_real_time_quotes_one = kpl_real_time_quotes.loc[
                kpl_real_time_quotes['symbol'] == company_one.symbol]

            if data_frame_util.is_not_empty(kpl_real_time_quotes_one):
                company_one_df['kpl_plate_name'] = list(kpl_real_time_quotes_one['plate_name_list'])[0]
                company_one_df['kpl_most_relative_name'] = \
                    list(kpl_real_time_quotes_one['most_relative_name'])[
                        0]
            company_one_df = set_kpl_data(kpl_real_time_quotes_one, company_one_df, company_one)

        if bool(1 - ("kpl_plate_name" in company_one_df.columns)) or bool(
                1 - ("kpl_most_relative_name" in company_one_df.columns)):
            company_one_df['kpl_plate_name'] = ""
            company_one_df['kpl_most_relative_name'] = ""
    except BaseException as e:
        logger.warning("设置开盘啦数据异常:{},{}", company_one.symbol, e)
    return company_one_df


def set_kpl_data(kpl_real_time_quotes_one, company_one_df, company_one):
    if data_frame_util.is_not_empty(kpl_real_time_quotes_one):
        company_one_df['kpl_plate_name'] = list(kpl_real_time_quotes_one['plate_name_list'])[0]
        company_one_df['kpl_most_relative_name'] = list(kpl_real_time_quotes_one['most_relative_name'])[
            0]
        symbol = company_one.symbol

        query = {'symbol': symbol, "index_class": kpl_constant.FIRST_INDEX}
        kpl_best_choose_index_detail = mongodb_util.find_query_data('kpl_best_choose_index_detail', query)
        if data_frame_util.is_not_empty(kpl_best_choose_index_detail):
            kpl_best_choose_index_detail = kpl_best_choose_index_detail[[
                "plate_code",
                "plate_name",
                "first_plate_code",
                "first_plate_name",
                "index_class"
            ]]

            # 去除空格
            kpl_best_choose_index_detail['plate_name'] = kpl_best_choose_index_detail['plate_name'].str.replace(' ', '')
            # 去除空格
            kpl_best_choose_index_detail['first_plate_name'] = kpl_best_choose_index_detail[
                'first_plate_name'].str.replace(' ', '')

            company_one_df.loc[:, 'kpl_plate_list_info'] = kpl_best_choose_index_detail.to_string(index=False)
    return company_one_df


# 获取可转债信息
@lru_cache(maxsize=None)
def get_kzz_debt_info():
    query = {}
    kzz_debt_info_df = mongodb_util.find_query_data(db_name_constant.KZZ_DEBT_INFO, query)
    kzz_debt_info_df = kzz_debt_info_df[[
        'symbol',
        'name',
        'stock_code',
        'apply_date',
        'list_date',
        'due_date'
    ]]
    return kzz_debt_info_df


def set_kzz_debt(company_one_df, symbol):
    kzz_debt_info_df_all = get_kzz_debt_info()
    kzz_debt_info_df = kzz_debt_info_df_all.loc[kzz_debt_info_df_all['stock_code'] == symbol]

    if data_frame_util.is_not_empty(kzz_debt_info_df):
        kzz_debt_info_df_list = kzz_debt_info_df.to_dict(orient='records')
        company_one_df['kzz_debt_list'] = [kzz_debt_info_df_list]
    return company_one_df


# 获取最近年报收入
def set_recent_year_income(symbol, company_one_df):
    query = {'symbol': symbol, "REPORT_TYPE": "年报"}
    em_stock_profit = mongodb_util.descend_query(query, db_name_constant.EM_STOCK_PROFIT, 'REPORT_DATE', 1)
    if data_frame_util.is_not_empty(em_stock_profit):
        company_one_df['operate_profit'] = list(em_stock_profit['OPERATE_PROFIT'])[0]
        company_one_df['operate_date_name'] = list(em_stock_profit['REPORT_DATE_NAME'])[0]
        total_operate_income = list(em_stock_profit['TOTAL_OPERATE_INCOME'])[0]
        # 金融机构大多收入计入在这个字段中
        if total_operate_income == 0:
            total_operate_income = list(em_stock_profit['OPERATE_INCOME'])[0]

        company_one_df['total_operate_income'] = total_operate_income
    else:
        company_one_df['operate_profit'] = 0
        company_one_df['total_operate_income'] = 0
        company_one_df['operate_date_name'] = '暂无年报'
    company_one_df['operate_profit'] = round(
        company_one_df['operate_profit'] / common_service_fun_api.HUNDRED_MILLION, 2)
    company_one_df['total_operate_income'] = round(
        company_one_df['total_operate_income'] / common_service_fun_api.HUNDRED_MILLION, 2)
    return company_one_df


# 计算真实流通比例
def set_calculate_circulation_ratio(symbol, now_str_day, company_one_df):
    query = {"symbol": symbol}
    stock_gdfx_free_top_1 = mongodb_util.descend_query(query, 'stock_gdfx_free_top_10', "period", 1)
    if stock_gdfx_free_top_1.shape[0] == 0:
        mv_circulation_ratio = 1
        qfii_number = 0
        qfii_type = 'A股'
        share_holder_sync_day = now_str_day
    else:
        period_time = list(stock_gdfx_free_top_1['period'])[0]

        query_free = {'symbol': symbol, 'period': period_time}
        stock_gdfx_free_top_10 = mongodb_util.find_query_data('stock_gdfx_free_top_10', query_free)

        stock_gdfx_free_top_10['shares_number_str'] = stock_gdfx_free_top_10['shares_number'].astype(str)

        stock_gdfx_free_top_10['id_key'] = stock_gdfx_free_top_10['symbol'] + '_' + stock_gdfx_free_top_10[
            'period'] + '_' + stock_gdfx_free_top_10.shares_number_str

        stock_gdfx_free_top_10.drop_duplicates('id_key', keep='last', inplace=True)

        # 排除香港结算公司 大于5%减持不用发公告  香港中央结算    HKSCC
        stock_gdfx_free_top_10['is_hk'] = stock_gdfx_free_top_10['shareholder_name'].apply(
            lambda shareholder_name: "HK" if shareholder_name.startswith('香港中央结算') or shareholder_name.startswith(
                'HKSCC') else "A")

        # 持股大于5% 减持需要发公告
        # 排除香港结算公司不发公共 小于5%减持不用发公告
        # 香港中央结算    HKSCC
        stock_free_top_greater_than_5 = stock_gdfx_free_top_10.loc[
            (stock_gdfx_free_top_10['circulation_ratio'] >= 5) & (stock_gdfx_free_top_10['is_hk'] == 'A')]

        stock_free_qfii = stock_gdfx_free_top_10.loc[stock_gdfx_free_top_10['shareholder_nature'] == 'QFII']

        share_holder_sync_day = list(stock_gdfx_free_top_10['create_day'])[0]

        # qfii 数量
        qfii_number = stock_free_qfii.shape[0]
        # qfii 类型
        qfii_type = set_qfii_type(qfii_number, stock_free_qfii.copy())

        circulation_ratio = sum(stock_free_top_greater_than_5['circulation_ratio'])
        mv_circulation_ratio = round((100 - circulation_ratio) / 100, 2)
        # 防止错误数据
        if mv_circulation_ratio < 0:
            mv_circulation_ratio = 1

    company_one_df['mv_circulation_ratio'] = mv_circulation_ratio
    company_one_df['qfii_type'] = qfii_type
    company_one_df['qfii_number'] = qfii_number
    company_one_df['share_holder_sync_day'] = share_holder_sync_day

    company_one_df = set_recent_debt_ratio(symbol, company_one_df.copy())

    return company_one_df


# 设置QFII持股
def set_qfii_type(qfii_number, stock_free_qfii):
    if qfii_number > 0:
        stock_free_qfii['new_change'] = stock_free_qfii['change']
        stock_free_qfii.loc[stock_free_qfii['change_ratio'] == 0, 'new_change'] = 0
        stock_free_qfii.loc[stock_free_qfii['change'] == '新进', 'new_change'] = \
            stock_free_qfii['shares_number']
        stock_free_qfii['new_change'] = stock_free_qfii['new_change'].astype(float)
        # 新进
        stock_free_qfii_new_in = stock_free_qfii.loc[stock_free_qfii['change'] == '新进']
        if data_frame_util.is_not_empty(stock_free_qfii_new_in):
            qfii_type = 1
            return qfii_type

        stock_free_qfii_add = stock_free_qfii.loc[
            (~stock_free_qfii['change'].isin(['不变', '新进'])) & (stock_free_qfii['new_change'] > 0)]

        if data_frame_util.is_not_empty(stock_free_qfii_add):
            # 增持
            qfii_type = 2
            return qfii_type

        stock_free_qfii_not_change = stock_free_qfii.loc[stock_free_qfii['change'] == '不变']

        if data_frame_util.is_not_empty(stock_free_qfii_not_change):
            # 不变
            qfii_type = 3
            return qfii_type

        stock_free_qfii_reduce = stock_free_qfii.loc[
            (~stock_free_qfii['change'].isin(['不变', '新进'])) & (stock_free_qfii['new_change'] < 0)]

        if data_frame_util.is_not_empty(stock_free_qfii_reduce):
            # 减少
            qfii_type = 4
            return qfii_type
    else:
        return 0


def set_recent_debt_ratio(symbol, company_one_df):
    query = {'symbol': symbol}

    xue_qiu_asset_debt_df = mongodb_util.descend_query(query, 'xue_qiu_asset_debt', 'report_date', 1)
    if data_frame_util.is_not_empty(xue_qiu_asset_debt_df):
        asset_liab_ratio = round(100 * list(xue_qiu_asset_debt_df['asset_liab_ratio'])[0], 2)
    else:
        asset_liab_ratio = 100

    company_one_df.loc[company_one_df['symbol'] == symbol, 'debt_ratio'] = asset_liab_ratio

    return company_one_df


if __name__ == '__main__':
    set_recent_debt_ratio('002213', None)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_scheduler.risk.financial.net_assets_check_api as net_assets_check_api
import mns_scheduler.risk.financial.annual_report_audit_check_api as annual_report_audit_check_api
import mns_scheduler.risk.financial.profit_income_check_api as profit_income_check_api


# 1.无保留意见/标准报告：报告没问题。（没有发现造假，但也不能保证为真）
#
# 2.带强调事项段的无保留意见：报告没问题，但是有亏损获对其可持续经营有重大疑虑（可能造假，至少是在粉饰报表）
#
# 3.保留意见报告：有问题，财务造假
#
# 4.否定意见报告：有很大问题
#
# 5.无法表示意见报告：不让查
#


#### 退市新规 ####
# 1 股价类:连续20个交易日估价低于1元
# 2 市值类: 主板小于5亿、创业板3亿
# 3 财务类: (1) 利润总额 净利润 扣非净利润三者最小值为负 且营业收入小于3亿 创业板营业收入小于1元
#          (2) 资不抵债


# 财报审核
def financial_report_check(new_report_df, period_time, period, report_type):
    # 年报审核
    if period == 4:
        # 年报审计意见
        annual_report_audit_check_api.annual_report_audit_check(new_report_df, period_time)
        # 年报收入利润check
        profit_income_check_api.profit_income_check(new_report_df, period_time, report_type)

    # 负债过高
    net_assets_check_api.net_assets_check(report_type, new_report_df, period_time)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

# 每月最大交易天数
MAX_TRADE_DAYS_PER_MONTH = 23
# 每周最大交易天数
MAX_TRADE_DAYS_PER_WEEK = 5


def handle_month_line(k_line_info, stock_qfq_daily, deal_days):
    # 上市2-23天
    if 1 < deal_days <= MAX_TRADE_DAYS_PER_MONTH:
        month_01 = round(sum(stock_qfq_daily['chg']), 2)
        k_line_info['sum_month'] = month_01
        k_line_info['month_num'] = 1
        k_line_info['month01'] = month_01
        k_line_info['month01_date'] = list(stock_qfq_daily.iloc[0:1]['date'])[0]
        # 上市23-23*2天
    elif (deal_days > MAX_TRADE_DAYS_PER_MONTH) \
            and (deal_days <= MAX_TRADE_DAYS_PER_MONTH * 2):
        stock_qfq_daily_month_01 = stock_qfq_daily.iloc[0:MAX_TRADE_DAYS_PER_MONTH]
        month_01 = round(sum(stock_qfq_daily_month_01['chg']), 2)
        k_line_length = stock_qfq_daily.shape[0]
        stock_qfq_daily_month_02 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_MONTH: k_line_length]
        month_02 = round(sum(stock_qfq_daily_month_02['chg']), 2)
        k_line_info['sum_month'] = round(month_01 + month_02, 2)
        k_line_info['month_num'] = 2
        k_line_info['month01'] = month_01
        k_line_info['month02'] = month_02
        k_line_info['month01_date'] = list(stock_qfq_daily_month_01.iloc[0:1]['date'])[0]
        if k_line_length != MAX_TRADE_DAYS_PER_MONTH:
            k_line_info['month02_date'] = list(stock_qfq_daily_month_02.iloc[0:1]['date'])[0]
        else:
            k_line_info['month02_date'] = '19890729'
    elif deal_days > MAX_TRADE_DAYS_PER_MONTH * 2:
        stock_qfq_daily_month_01 = stock_qfq_daily.iloc[0:MAX_TRADE_DAYS_PER_MONTH]
        month_01 = round(sum(stock_qfq_daily_month_01['chg']), 2)
        stock_qfq_daily_month_02 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_MONTH:MAX_TRADE_DAYS_PER_MONTH * 2]
        month_02 = round(sum(stock_qfq_daily_month_02['chg']), 2)
        k_line_info['month01_date'] = list(stock_qfq_daily_month_01.iloc[0:1]['date'])[0]
        k_line_info['month02_date'] = list(stock_qfq_daily_month_02.iloc[0:1]['date'])[0]
        k_line_info['sum_month'] = round(month_01 + month_02, 2)
        k_line_info['month_num'] = 2
        k_line_info['month01'] = month_01
        k_line_info['month02'] = month_02

    return k_line_info


def handle_week_line(k_line_info, stock_qfq_daily, deal_days):
    if 1 < deal_days <= MAX_TRADE_DAYS_PER_WEEK:
        week_01 = round(sum(stock_qfq_daily['chg']), 2)
        k_line_info['sum_week'] = week_01
        k_line_info['week_num'] = 1
        k_line_info['week01'] = week_01
        k_line_info['week_last_day'] = list(stock_qfq_daily.iloc[0:1]['date'])[0]
    elif MAX_TRADE_DAYS_PER_WEEK < deal_days <= MAX_TRADE_DAYS_PER_WEEK * 2:
        stock_qfq_daily_week_01 = stock_qfq_daily.iloc[0:MAX_TRADE_DAYS_PER_WEEK]
        stock_qfq_daily_week_02 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_WEEK:MAX_TRADE_DAYS_PER_WEEK * 2]
        week_01 = round(sum(stock_qfq_daily_week_01['chg']), 2)
        week_02 = round(sum(stock_qfq_daily_week_02['chg']), 2)
        k_line_info['sum_week'] = week_01 + week_02
        k_line_info['week_num'] = 2
        k_line_info['week01'] = week_01
        k_line_info['week02'] = week_02
        k_line_info['week_last_day'] = list(stock_qfq_daily_week_01.iloc[0:1]['date'])[0]
    elif MAX_TRADE_DAYS_PER_WEEK < deal_days <= MAX_TRADE_DAYS_PER_WEEK * 3:
        stock_qfq_daily_week_01 = stock_qfq_daily.iloc[0:MAX_TRADE_DAYS_PER_WEEK]
        stock_qfq_daily_week_02 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_WEEK: MAX_TRADE_DAYS_PER_WEEK * 2]
        stock_qfq_daily_week_03 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_WEEK * 2: MAX_TRADE_DAYS_PER_WEEK * 3]
        week_01 = round(sum(stock_qfq_daily_week_01['chg']), 2)
        week_02 = round(sum(stock_qfq_daily_week_02['chg']), 2)
        week_03 = round(sum(stock_qfq_daily_week_03['chg']), 2)
        k_line_info['sum_week'] = week_01 + week_02 + week_03
        k_line_info['week_num'] = 3
        k_line_info['week01'] = week_01
        k_line_info['week02'] = week_02
        k_line_info['week03'] = week_03
        k_line_info['week_last_day'] = list(stock_qfq_daily_week_01.iloc[0:1]['date'])[0]

    elif MAX_TRADE_DAYS_PER_WEEK * 3 < deal_days:
        stock_qfq_daily_week_01 = stock_qfq_daily.iloc[0:MAX_TRADE_DAYS_PER_WEEK]
        stock_qfq_daily_week_02 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_WEEK:MAX_TRADE_DAYS_PER_WEEK * 2]
        stock_qfq_daily_week_03 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_WEEK * 2: MAX_TRADE_DAYS_PER_WEEK * 3]
        stock_qfq_daily_week_04 = stock_qfq_daily.iloc[MAX_TRADE_DAYS_PER_WEEK * 3: MAX_TRADE_DAYS_PER_WEEK * 4]
        week_01 = round(sum(stock_qfq_daily_week_01['chg']), 2)
        week_02 = round(sum(stock_qfq_daily_week_02['chg']), 2)
        week_03 = round(sum(stock_qfq_daily_week_03['chg']), 2)
        week_04 = round(sum(stock_qfq_daily_week_04['chg']), 2)
        k_line_info['sum_week'] = week_01 + week_02 + week_03 + week_04
        k_line_info['week_num'] = 4
        k_line_info['week01'] = week_01
        k_line_info['week02'] = week_02
        k_line_info['week03'] = week_03
        k_line_info['week04'] = week_04
        k_line_info['week_last_day'] = stock_qfq_daily_week_01.iloc[0:1]['date']
    return k_line_info
